@@ -327,7 +327,7 @@ def edit_config(model_selected, input_config_dir, output_config_dir, num_steps,
     print(f"Configuration successfully edited and saved at {output_config_dir}")
 
 
-def train(ckpt_dir='', config='', train_steps=1000, use_tpu=False, checkpoint_every_n=100,
+def train(ckpt_dir='', config_dir='', train_steps=1000, use_tpu=False, checkpoint_every_n=100,
           record_summaries=True):
 
     if config.endswith('.config'):
@@ -539,7 +539,7 @@ def tf_events_to_dict(path, type=''):
 
     return log_dict
 
-def export_graph(ckpt_dir, exported_model_dir, pipeline_config_dir,
+def export_graph(ckpt_dir, exported_model_dir, config_dir,
     config_override='', input_type="image_tensor", use_side_inputs=False,
     side_input_shapes='', side_input_types='', side_input_names=''):
     ''' Export your checkpoint to a saved_model.pb file
@@ -550,7 +550,7 @@ def export_graph(ckpt_dir, exported_model_dir, pipeline_config_dir,
                 pipeline_çonfig_path: The directory where you protobuf configuration is located.
 
     '''
-    pipeline_config_path = os.path.join(pipeline_config_dir,"pipeline.config")
+    pipeline_config_path = os.path.join(config_dir,"pipeline.config")
     pipeline_config = pipeline_pb2.TrainEvalPipelineConfig()
     with tf.io.gfile.GFile(pipeline_config_path, 'r') as f:
         text_format.Merge(f.read(), pipeline_config)
